import urllib

from . import http, dict, errors

noresponse = "eyy sorry im just a dog.."

def honker():
    try:
        return http.get("/honker.php?tags=big_breasts")["url"]
    except Exception as e:
        raise errors.NothingFound(noresponse)


def badonkers():
    try:
        return http.get("/honker.php?tags=large_breasts")["url"]
    except Exception as e:
        raise errors.NothingFound(noresponse)


def hhonker():
    try:
        return http.get("/r.php?tags?=big_breasts")["url"]
    except Exception as e:
        raise errors.NothingFound(noresponse)

def ass():
    try:
        return http.get("/r.php?tags?=ass")["url"]
    except Exception as e:
        raise errors.NothingFound(noresponse)

def hass():
    try:
        return http.get("/r.php?tags?=ass")["url"]
    except Exception as e:
        raise errors.NothingFound(noresponse)

def thicc():
    try:
        return http.get("/r34/?tags=armpits")["url"]
    except Exception as e:
        raise errors.NothingFound(noresponse)

def hthicc():
    try:
        return http.get("/r34/?tags=armpit_hair")["url"]
    except Exception as e:
        raise errors.NothingFound(noresponse)

def milf():
    try:
        return http.get("/r34/?tags=armpit_licking")["url"]
    except Exception as e:
        raise errors.NothingFound(noresponse)

def hmilf():
    try:
        return http.get("/r34/?tags=smell")["url"]
    except Exception as e:
        raise errors.NothingFound(noresponse)

def milk():
    try:
        return http.get("/r34/?tags=pantyhose")["url"]
    except Exception as e:
        raise errors.NothingFound(noresponse)

def hmilk():
    try:
        return http.get("/r34/?tags=large_breasts")["url"]
    except Exception as e:
        raise errors.NothingFound(noresponse)

def booty():
    try:
        return http.get("/r34/?tags=blush")["url"]
    except Exception as e:
        raise errors.NothingFound(noresponse)

def hbooty():
    try:
        return http.get("/r34/?tags=blowjob")["url"]
    except Exception as e:
        raise errors.NothingFound(noresponse)

def belly():
    try:
        return http.get("/r34/?tags=masturbation")["url"]
    except Exception as e:
        raise errors.NothingFound(noresponse)

def hbelly():
    try:
        return http.get("/r34/?tags=pervert")["url"]
    except Exception as e:
        raise errors.NothingFound(noresponse)

def gifTits():
    try:
        return http.get("/r34/?tags=pubic_hair")["url"]
    except Exception as e:
        raise errors.NothingFound(noresponse)

def gifPussy():
    try:
        return http.get("/r34/?tags=sweat")["url"]
    except Exception as e:
        raise errors.NothingFound(noresponse)

def gifAss():
    try:
        return http.get("/r34/?tags=footjob")["url"]
    except Exception as e:
        raise errors.NothingFound(noresponse)

def gifMissionary():
    try:
        return http.get("/r34/?tags=foot_licking")["url"]
    except Exception as e:
        raise errors.NothingFound(noresponse)

def gifCowgirl():
    try:
        return http.get("/r34/?tags=housewife")["url"]
    except Exception as e:
        raise errors.NothingFound(noresponse)

def gifBj():
    try:
        return http.get("/r34/?tags=milf")["url"]
    except Exception as e:
        raise errors.NothingFound(noresponse)

def gifCumshots():
    try:
        return http.get("/r34/?tags=school_uniform")["url"]
    except Exception as e:
        raise errors.NothingFound(noresponse)

def random():
    try:
        return http.get("/r34/?tags=bikini")["url"]
    except Exception as e:
        raise errors.NothingFound(noresponse)

def ahegao():
    try:
        return http.get("/r34/?tags=cowgirl_position")["url"]
    except Exception as e:
        raise errors.NothingFound(noresponse)
